@@ -267,16 +267,13 @@ class TickerDax:
             ) as connected_socket:
                 self._logger.info(f"> Connected to {uri}")
                 while True:
-                    try:
-                        data = json.loads(await connected_socket.recv())
-                        symbol = data.get('symbol')
-                        timestamp = data.get('id')
-                        if symbol and timestamp:
-                            for key in self._get_cache_keys(self._format_route(route), [symbol], [timestamp]):
-                                self._redis_client.set(key, json.dumps(data))
-                                self._logger.info(f'Cached: {pformat(data)}')
-                    except Exception as error:
-                        self._logger.error(error)
+                    data = json.loads(await connected_socket.recv())
+                    symbol = data.get('symbol')
+                    timestamp = data.get('id')
+                    if symbol and timestamp:
+                        for key in self._get_cache_keys(self._format_route(route), [symbol], [timestamp]):
+                            self._redis_client.set(key, json.dumps(data))
+                            self._logger.info(f'Cached: {pformat(data)}')
 
         except InvalidStatusCode as error:
             if error.status_code == 401:
